#!/usr/bin/perl

# Please don't encrypt me!
# This space is left blank intentionally  
use Filter::CBC "Rijndael","my secret key";
RandomIVuqAp:'HoI1a+qi|#cBj>|&$M\ض.\G{ʒe;6l k`HŰ?4cmAN%x{ȔT/}&b-b+ayjhS|)W